import { Program } from "@/types/program";

interface SearchProgramsParams {
  query?: string;
  filters?: {
    level?: string;
    duration?: string;
    tuition?: [number, number];
  };
  page: number;
}

const ITEMS_PER_PAGE = 20;
const TOTAL_PROGRAMS = 1000;

export async function searchPrograms({ 
  query, 
  filters, 
  page 
}: SearchProgramsParams): Promise<{ 
  programs: Program[];
  hasNextPage: boolean;
  nextPage: number;
}> {
  // Simulate API delay
  await new Promise((resolve) => setTimeout(resolve, 1000));

  const programs: Program[] = Array.from({ length: ITEMS_PER_PAGE }, (_, i) => {
    const globalIndex = (page - 1) * ITEMS_PER_PAGE + i;
    
    return {
      id: `program-${globalIndex}`,
      name: `${["Bachelor's", "Master's", "PhD"][globalIndex % 3]} in ${
        ["Computer Science", "Business Administration", "Data Science", "Engineering"][
          globalIndex % 4
        ]
      }`,
      universityName: `University ${globalIndex + 1}`,
      universityLogo: `https://images.unsplash.com/photo-${1562774053 + (globalIndex % 10)}-701939374585?w=800&q=80`,
      level: ["Undergraduate", "Graduate", "Doctorate"][globalIndex % 3],
      duration: `${[2, 3, 4][globalIndex % 3]} years`,
      tuition: `$${(20000 + (globalIndex % 30000)).toLocaleString()}/year`,
      nextIntake: ["Fall 2024", "Spring 2025", "Fall 2025"][globalIndex % 3],
      features: [
        "Industry Partnerships",
        "Research Opportunities",
        "Internship Program",
        "Study Abroad Options"
      ].slice(0, 2 + (globalIndex % 3)),
      description: "A comprehensive program designed to prepare students for successful careers...",
      requirements: [
        "Bachelor's degree with 3.0 GPA",
        "Letters of recommendation",
        "Statement of purpose",
        "Resume/CV"
      ],
      applicationDeadline: new Date(
        Date.now() + (1 + globalIndex % 12) * 30 * 24 * 60 * 60 * 1000
      ).toISOString(),
    };
  });

  return {
    programs,
    hasNextPage: page * ITEMS_PER_PAGE < TOTAL_PROGRAMS,
    nextPage: page + 1,
  };
}